==> payu-sdk-4.3.2-sources.jar: com/payu/india/Model/CardInformation.java <==
//    Copyright (c) 2014 - 2015 payu@india.com
//
//    Permission is hereby granted, free of charge, to any person obtaining a copy
//    of this software and associated documentation files (the "Software"), to deal
//    in the Software without restriction, including without limitation the rights
//    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//    copies of the Software, and to permit persons to whom the Software is
//    furnished to do so, subject to the following conditions:
//
//    The above copyright notice and this permission notice shall be included in
//    all copies or substantial portions of the Software.
//
//    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//    THE SOFTWARE.

package com.payu.india.Model;

import android.os.Parcel;
import android.os.Parcelable;

/**
 * Created by franklin on 7/1/15.
 * Simple bean implementation of card information
 * When the app uses {@link com.payu.india.Tasks.GetCardInformationTask} the response will be passed as {@link CardInformation}
 * along with the {@link PostData} in {@link PayuResponse}
 */
public class CardInformation implements Parcelable {

    public static final Creator<CardInformation> CREATOR = new Creator<CardInformation>() {
        @Override
        public CardInformation createFromParcel(Parcel in) {
            return new CardInformation(in);
        }

        @Override
        public CardInformation[] newArray(int size) {
            return new CardInformation[size];
        }
    };
    private Boolean isDomestic;
    private String issuingBank;
    private String cardCategory;
    private String cardType;

    public CardInformation() {
    }

    protected CardInformation(Parcel in) {
    }

    public String getIssuingBank() {
        return issuingBank;
    }

    public void setIssuingBank(String issuingBank) {
        this.issuingBank = issuingBank;
    }

    public Boolean getIsDomestic() {
        return isDomestic;
    }

    public void setIsDomestic(Boolean isDomestic) {
        this.isDomestic = isDomestic;
    }

    public String getCardCategory() {
        return cardCategory;
    }

    public void setCardCategory(String cardCategory) {
        this.cardCategory = cardCategory;
    }

    public String getCardType() {
        return cardType;
    }

    public void setCardType(String cardType) {
        this.cardType = cardType;
    }

    @Override
    public int describeContents() {
        return 0;
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
    }
}

==> payu-sdk-4.4.2-sources.jar: com/payu/india/Model/CardInformation.java <==
//    Copyright (c) 2014 - 2015 payu@india.com
//
//    Permission is hereby granted, free of charge, to any person obtaining a copy
//    of this software and associated documentation files (the "Software"), to deal
//    in the Software without restriction, including without limitation the rights
//    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//    copies of the Software, and to permit persons to whom the Software is
//    furnished to do so, subject to the following conditions:
//
//    The above copyright notice and this permission notice shall be included in
//    all copies or substantial portions of the Software.
//
//    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//    THE SOFTWARE.

package com.payu.india.Model;

import android.os.Parcel;
import android.os.Parcelable;

/**
 * Created by franklin on 7/1/15.
 * Simple bean implementation of card information
 * When the app uses {@link com.payu.india.Tasks.GetCardInformationTask} the response will be passed as {@link CardInformation}
 * along with the {@link PostData} in {@link PayuResponse}
 */
public class CardInformation implements Parcelable {

    private Boolean isDomestic; // Domestic / international
    private String issuingBank; // Name of the issuing bank
    private String cardCategory; // Card category (VISA, MAST, etc)
    private String cardType; // Card type (CC, DC)

    public CardInformation() {
    }


    protected CardInformation(Parcel in) {
        issuingBank = in.readString();
        cardCategory = in.readString();
        cardType = in.readString();
    }

    public static final Creator<CardInformation> CREATOR = new Creator<CardInformation>() {
        @Override
        public CardInformation createFromParcel(Parcel in) {
            return new CardInformation(in);
        }

        @Override
        public CardInformation[] newArray(int size) {
            return new CardInformation[size];
        }
    };

    public String getIssuingBank() {
        return issuingBank;
    }

    public void setIssuingBank(String issuingBank) {
        this.issuingBank = issuingBank;
    }

    public Boolean getIsDomestic() {
        return isDomestic;
    }

    public void setIsDomestic(Boolean isDomestic) {
        this.isDomestic = isDomestic;
    }

    public String getCardCategory() {
        return cardCategory;
    }

    public void setCardCategory(String cardCategory) {
        this.cardCategory = cardCategory;
    }

    public String getCardType() {
        return cardType;
    }

    public void setCardType(String cardType) {
        this.cardType = cardType;
    }

    @Override
    public int describeContents() {
        return 0;
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeString(issuingBank);
        dest.writeString(cardCategory);
        dest.writeString(cardType);
    }
}
